@@ -35,6 +35,10 @@ mkdir -m 700 -p $DIR 2> /dev/null
 
 rsync --quiet \
     --archive --hard-links --sparse --delete-excluded \
+    --numeric-ids \
     -e 'ssh -i /root/.ssh/backup' root@$IP::root \
-    --exclude dev/pts --exclude proc --exclude sys \
-    $DIR
+    --exclude '/dev/pts/*' --exclude '/proc/*' --exclude '/sys/*' \
+    --exclude '/mnt/*/*' --exclude '/fs-available/*/*' \
+    --exclude '/var/cache/apt/archives/*' \
+    --exclude '/var/cache/apt-proxy/*'
+   $DIR
