@@ -1,7 +1,7 @@
 #!/bin/bash
 
 IP=$1
-if [ -z IP ]; then
+if [ -z "$IP" ]; then
     echo "Usage: $0 IP"
     exit 1
 fi
@@ -14,4 +14,4 @@ echo "Teleporting us to the remote machine via rsync"
 ssh root@$IP aptitude --assume-yes install rsync
 rsync -av . root@$IP:post-install
 
-ssh -t root@$IP sh post-install/client.txt
+#ssh -t root@$IP cd post-install \&\& sh packages.sh
